# Available Modules

## Bio

| Module | Description |
| ------ | ----------- |
| [FastQC](http://www.bioinformatics.babraham.ac.uk/projects/download.html) | A quality control application for high throughput sequence data |
| [GATK](http://www.broadinstitute.org/gatk/) | The Genome Analysis Toolkit or GATK is a software package developed at the Broad Institute to analyse next-generation resequencing data. The toolkit offers a wide variety of tools, with a primary focus on variant discovery and genotyping as well as strong emphasis on data quality assurance. Its robust architecture, powerful processing engine and high-performance computing features make it capable of taking on projects of any size. |
| [SnpEff](http://snpeff.sourceforge.net/) | Genetic variant annotation and effect prediction toolbox. |

## Cae

| Module | Description |
| ------ | ----------- |
| COMSOL | &nbsp; |
| [OpenFOAM](http://www.openfoam.com/) | OpenFOAM is a free, open source CFD software package. OpenFOAM has an extensive range of features to solve anything from complex fluid flows involving chemical reactions, turbulence and heat transfer, to solid dynamics and electromagnetics. |

## Chem

| Module | Description |
| ------ | ----------- |
| [ABINIT](http://www.abinit.org/) | Abinit is a plane wave pseudopotential code for doing condensed phase electronic structure calculations using DFT. |
| [Libint](https://sourceforge.net/p/libint/) | Libint library is used to evaluate the traditional (electron repulsion) and certain novel two-body matrix elements (integrals) over Cartesian Gaussian functions used in modern atomic and molecular theory. |
| [libxc](http://www.tddft.org/programs/octopus/wiki/index.php/Libxc) | Libxc is a library of exchange-correlation functionals for density-functional theory. The aim is to provide a portable, well tested and reliable set of exchange and correlation functionals. |

## Compiler

| Module | Description |
| ------ | ----------- |
| [GCC](http://gcc.gnu.org/) | The GNU Compiler Collection includes front ends for C, C++, Objective-C, Fortran, Java, and Ada, as well as libraries for these languages (libstdc++, libgcj,...). |
| GCCcore | &nbsp; |
| icc | &nbsp; |
| [ifort](http://software.intel.com/en-us/intel-compilers/) | Fortran compiler from Intel |
| [LLVM](http://llvm.org/) | The LLVM Core libraries provide a modern source- and target-independent optimizer, along with code generation support for many popular CPUs (as well as some less common ones!) These libraries are built around a well specified code representation known as the LLVM intermediate representation ("LLVM IR"). The LLVM Core libraries are well documented, and it is particularly easy to invent your own language (or port an existing compiler) to use LLVM as an optimizer and code generator. |

## Data

| Module | Description |
| ------ | ----------- |
| [GDAL](http://www.gdal.org/) | GDAL is a translator library for raster geospatial data formats that is released under an X/MIT style Open Source license by the Open Source Geospatial Foundation. As a library, it presents a single abstract data model to the calling application for all supported formats. It also comes with a variety of useful commandline utilities for data translation and processing. |
| [HDF5](http://www.hdfgroup.org/HDF5/) | HDF5 is a unique technology suite that makes possible the management of extremely large and complex data collections. |
| [netCDF](http://www.unidata.ucar.edu/software/netcdf/) | NetCDF (network Common Data Form) is a set of software libraries and machine-independent data formats that support the creation, access, and sharing of array-oriented scientific data. |
| [netCDF-Fortran](http://www.unidata.ucar.edu/software/netcdf/) | NetCDF (network Common Data Form) is a set of software libraries and machine-independent data formats that support the creation, access, and sharing of array-oriented scientific data. |

## Devel

| Module | Description |
| ------ | ----------- |
| [Autoconf](http://www.gnu.org/software/autoconf/) | Autoconf is an extensible package of M4 macros that produce shell scripts to automatically configure software source code packages. These scripts can adapt the packages to many kinds of UNIX-like systems without manual user intervention. Autoconf creates a configuration script for a package from a template file that lists the operating system features that the package can use, in the form of M4 macro calls. |
| [Automake](http://www.gnu.org/software/automake/automake.html) | Automake: GNU Standards-compliant Makefile generator |
| [Autotools](http://autotools.io) | This bundle collect the standard GNU build tools: Autoconf, Automake and libtool |
| [Boost](http://www.boost.org/) | Boost provides free peer-reviewed portable C++ source libraries. |
| [CMake](http://www.cmake.org) | CMake, the cross-platform, open-source build system. CMake is a family of tools designed to build, test and package software. |
| [Doxygen](http://www.doxygen.org) | Doxygen is a documentation system for C++, C, Java, Objective-C, Python, IDL (Corba and Microsoft flavors), Fortran, VHDL, PHP, C#, and to some extent D. |
| [M4](http://www.gnu.org/software/m4/m4.html) | GNU M4 is an implementation of the traditional Unix macro processor. It is mostly SVR4 compatible although it has some extensions (for example, handling more than 9 positional parameters to macros). GNU M4 also has built-in functions for including files, running shell commands, doing arithmetic, etc. |
| [make](http://www.gnu.org/software/make/make.html) | make-3.82: GNU version of make utility |
| [Mako](http://www.makotemplates.org) | A super-fast templating language that borrows the best ideas from the existing templating languages |
| [Maven](http://maven.apache.org/index.html) | Binary maven install, Apache Maven is a software project management and comprehension tool. Based on the concept of a project object model (POM), Maven can manage a project's build, reporting and documentation from a central piece of information. |
| [ncurses](http://www.gnu.org/software/ncurses/) | The Ncurses (new curses) library is a free software emulation of curses in System V Release 4.0, and more. It uses Terminfo format, supports pads and color and multiple highlights and forms characters and function-key mapping, and has all the other SYSV-curses enhancements over BSD Curses. |
| [PCRE](http://www.pcre.org/) | The PCRE library is a set of functions that implement regular expression pattern matching using the same syntax and semantics as Perl 5. |
| [pkg-config](http://www.freedesktop.org/wiki/Software/pkg-config/) | pkg-config is a helper tool used when compiling applications and libraries. It helps you insert the correct compiler options on the command line so an application can use gcc -o test test.c `pkg-config --libs --cflags glib-2.0` for instance, rather than hard-coding values on where to find glib (or other libraries). |
| [Qt](http://qt-project.org/) | Qt is a comprehensive cross-platform C++ application framework. |
| [Qt5](http://qt.io/) | Qt is a comprehensive cross-platform C++ application framework. |
| [SQLite](http://www.sqlite.org/) | SQLite: SQL Database Engine in a C Library |
| [SWIG](http://www.swig.org/) | SWIG is a software development tool that connects programs written in C and C++ with a variety of high-level programming languages. |
| [xorg-macros](http://cgit.freedesktop.org/xorg/util/macros) | X.org macros utilities. |

## Lang

| Module | Description |
| ------ | ----------- |
| [Bison](http://www.gnu.org/software/bison) | Bison is a general-purpose parser generator that converts an annotated context-free grammar into a deterministic LR or generalized LR (GLR) parser employing LALR(1) parser tables. |
| flex | &nbsp; |
| [Java](http://java.com/) | Java Platform, Standard Edition (Java SE) lets you develop and deploy Java applications on desktops and servers. |
| [Lua](http://www.lua.org/) | Lua is a powerful, fast, lightweight, embeddable scripting language. Lua combines simple procedural syntax with powerful data description constructs based on associative arrays and extensible semantics. Lua is dynamically typed, runs by interpreting bytecode for a register-based virtual machine, and has automatic memory management with incremental garbage collection, making it ideal for configuration, scripting, and rapid prototyping. |
| [Mono](http://mono-framework.com) | An open source, cross-platform, implementation of C# and the CLR that is binary compatible with Microsoft.NET. |
| [NASM](http://www.nasm.us/) | NASM: General-purpose x86 assembler |
| [OpenCL-runtime](https://software.intel.com/en-us/intel-opencl) | OpenCL™ is the first open, royalty-free standard for cross-platform, parallel programming of modern processors found in personal computers, servers and handheld/embedded devices. OpenCL (Open Computing Language) greatly improves speed and responsiveness for a wide spectrum of applications in numerous market categories from gaming and entertainment to scientific and medical software. |
| [Perl](http://www.perl.org/) | Larry Wall's Practical Extraction and Report Language |
| [Python](http://python.org/) | Python is a programming language that lets you work more quickly and integrate your systems more effectively. |
| [R](http://www.r-project.org/) | R is a free software environment for statistical computing and graphics. |
| [Tcl](http://www.tcl.tk/) | Tcl (Tool Command Language) is a very powerful but easy to learn dynamic programming language, suitable for a very wide range of uses, including web and desktop applications, networking, administration, testing and many more. |

## Lib

| Module | Description |
| ------ | ----------- |
| [libdrm](http://dri.freedesktop.org) | Direct Rendering Manager runtime library. |
| [libffi](http://sourceware.org/libffi/) | The libffi library provides a portable, high level programming interface to various calling conventions. This allows a programmer to call any function specified by a call interface description at run-time. |
| [libjpeg-turbo](http://sourceforge.net/libjpeg-turbo/) | libjpeg-turbo is a fork of the original IJG libjpeg which uses SIMD to accelerate baseline JPEG compression and decompression. libjpeg is a library that implements JPEG image encoding, decoding and transcoding. |
| [libpng](http://www.libpng.org/pub/png/libpng.html) | libpng is the official PNG reference library |
| [libpthread-stubs](http://xcb.freedesktop.org/) | The X protocol C-language Binding (XCB) is a replacement for Xlib featuring a small footprint, latency hiding, direct access to the protocol, improved threading support, and extensibility. |
| [libreadline](http://cnswww.cns.cwru.edu/php/chet/readline/rltop.html) | The GNU Readline library provides a set of functions for use by applications that allow users to edit command lines as they are typed in. Both Emacs and vi editing modes are available. The Readline library includes additional functions to maintain a list of previously-entered command lines, to recall and perhaps reedit those lines, and perform csh-like history expansion on previous commands. |
| [libsndfile](http://www.mega-nerd.com/libsndfile) | Libsndfile is a C library for reading and writing files containing sampled sound (such as MS Windows WAV and the Apple/SGI AIFF format) through one standard library interface. |
| [LibTIFF](http://www.remotesensing.org/libtiff/) | tiff: Library and tools for reading and writing TIFF data files |
| libtool | &nbsp; |
| [libxml2](http://xmlsoft.org/) | Libxml2 is the XML C parser and toolchain developed for the Gnome project (but usable outside of the Gnome platform). |
| [nettle](http://www.lysator.liu.se/~nisse/nettle/) | Nettle is a cryptographic library that is designed to fit easily in more or less any context: In crypto toolkits for object-oriented languages (C++, Python, Pike, ...), in applications like LSH or GNUPG, or even in kernel space. |
| [PROJ](http://trac.osgeo.org/proj/) | Program proj is a standard Unix filter function which converts geographic longitude and latitude coordinates into cartesian coordinates |
| [tbb](http://software.intel.com/en-us/articles/intel-tbb/) | Intel Threading Building Blocks 4.0 (Intel TBB) is a widely used, award-winning C++ template library for creating reliable, portable, and scalable parallel applications. Use Intel TBB for a simple and rapid way of developing robust task-based parallel applications that scale to available processor cores, are compatible with multiple environments, and are easier to maintain. Intel TBB is the most proficient way to implement future-proof parallel applications that tap into the power and performance of multicore and manycore hardware platforms. |
| [zlib](http://www.zlib.net/) | zlib is designed to be a free, general-purpose, legally unencumbered -- that is, not covered by any patents -- lossless data-compression library for use on virtually any computer hardware and operating system. |

## Math

| Module | Description |
| ------ | ----------- |
| [Eigen](http://eigen.tuxfamily.org/index.php?title=Main_Page) | Eigen is a C++ template library for linear algebra: matrices, vectors, numerical solvers, and related algorithms. |
| [GEOS](http://trac.osgeo.org/geos) | GEOS (Geometry Engine - Open Source) is a C++ port of the Java Topology Suite (JTS) |
| GMP | &nbsp; |
| [METIS](http://glaros.dtc.umn.edu/gkhome/metis/metis/overview) | METIS is a set of serial programs for partitioning graphs, partitioning finite element meshes, and producing fill reducing orderings for sparse matrices. The algorithms implemented in METIS are based on the multilevel recursive-bisection, multilevel k-way, and multi-constraint partitioning schemes. |
| [MPFR](http://www.mpfr.org) | The MPFR library is a C library for multiple-precision floating-point computations with correct rounding. |
| [SCOTCH](http://gforge.inria.fr/projects/scotch/) | Software package and libraries for sequential and parallel graph partitioning, static mapping, and sparse matrix block ordering, and sequential mesh and hypergraph partitioning. |

## Mpi

| Module | Description |
| ------ | ----------- |
| [impi](http://software.intel.com/en-us/intel-mpi-library/) | The Intel(R) MPI Library for Linux* OS is a multi-fabric message passing library based on ANL MPICH2 and OSU MVAPICH2. The Intel MPI Library for Linux OS implements the Message Passing Interface, version 2 (MPI-2) specification. |
| [OpenMPI](http://www.open-mpi.org/) | The Open MPI Project is an open source MPI-2 implementation. |

## Numlib

| Module | Description |
| ------ | ----------- |
| [CGAL](http://www.cgal.org/) | The goal of the CGAL Open Source Project is to provide easy access to efficient and reliable geometric algorithms in the form of a C++ library. |
| [cuDNN](https://developer.nvidia.com/cudnn) | The NVIDIA CUDA Deep Neural Network library (cuDNN) is a GPU-accelerated library of primitives for deep neural networks. |
| [FFTW](http://www.fftw.org) | FFTW is a C subroutine library for computing the discrete Fourier transform (DFT) in one or more dimensions, of arbitrary input size, and of both real and complex data. |
| [imkl](http://software.intel.com/en-us/intel-mkl/) | Intel Math Kernel Library is a library of highly optimized, extensively threaded math routines for science, engineering, and financial applications that require maximum performance. Core math functions include BLAS, LAPACK, ScaLAPACK, Sparse Solvers, Fast Fourier Transforms, Vector Math, and more. |
| [NLopt](http://ab-initio.mit.edu/wiki/index.php/NLopt) | NLopt is a free/open-source library for nonlinear optimization, providing a common interface for a number of different free optimization routines available online as well as original implementations of various other algorithms. |
| [OpenBLAS](http://xianyi.github.com/OpenBLAS/) | OpenBLAS is an optimized BLAS library based on GotoBLAS2 1.13 BSD version. |
| [ScaLAPACK](http://www.netlib.org/scalapack/) | The ScaLAPACK (or Scalable LAPACK) library includes a subset of LAPACK routines redesigned for distributed memory MIMD parallel computers. |

## Phys

| Module | Description |
| ------ | ----------- |
| [VASP](http://www.vasp.at) | The Vienna Ab initio Simulation Package (VASP) is a computer program for atomic scale materials modelling, e.g. electronic structure calculations and quantum-mechanical molecular dynamics, from first principles. |

## System

| Module | Description |
| ------ | ----------- |
| [CUDA](https://developer.nvidia.com/cuda-toolkit) | CUDA (formerly Compute Unified Device Architecture) is a parallel computing platform and programming model created by NVIDIA and implemented by the graphics processing units (GPUs) that they produce. CUDA gives developers access to the virtual instruction set and memory of the parallel computational elements in CUDA GPUs. |
| [hwloc](http://www.open-mpi.org/projects/hwloc/) | The Portable Hardware Locality (hwloc) software package provides a portable abstraction (across OS, versions, architectures, ...) of the hierarchical topology of modern architectures, including NUMA memory nodes, sockets, shared caches, cores and simultaneous multithreading. It also gathers various system attributes such as cache and memory information as well as the locality of I/O devices such as network interfaces, InfiniBand HCAs or GPUs. It primarily aims at helping applications with gathering information about modern computing hardware so as to exploit it accordingly and efficiently. |
| [libpciaccess](http://cgit.freedesktop.org/xorg/lib/libpciaccess/) | Generic PCI access library. |

## Toolchain

| Module | Description |
| ------ | ----------- |
| [foss]((none)) | GNU Compiler Collection (GCC) based compiler toolchain, including OpenMPI for MPI support, OpenBLAS (BLAS and LAPACK support), FFTW and ScaLAPACK. |
| [GNU](http://www.gnu.org/software/) | Compiler-only toolchain with GCC and binutils. |
| [gompi]((none)) | GNU Compiler Collection (GCC) based compiler toolchain, including OpenMPI for MPI support. |
| [iccifort](http://software.intel.com/en-us/intel-cluster-toolkit-compiler/) | Intel C, C++ and Fortran compilers |
| [iimpi](http://software.intel.com/en-us/intel-cluster-toolkit-compiler/) | Intel C/C++ and Fortran compilers, alongside Intel MPI. |
| [intel](http://software.intel.com/en-us/intel-cluster-toolkit-compiler/) | Intel Cluster Toolkit Compiler Edition provides Intel C/C++ and Fortran compilers, Intel MPI & Intel MKL. |
| [PRACE](http://www.prace-ri.eu/PRACE-Common-Production) | The PRACE Common Production Environment (PCPE) is a set of software tools and libraries that are planned to be available on all PRACE execution sites. The PCPE also defines a set of environment variables that try to make compilation on all sites as homogeneous and simple as possible. |
| [Py](https://www.python.org) | Python 2.7 toolchain |

## Tools

| Module | Description |
| ------ | ----------- |
| [Bash](http://www.gnu.org/software/bash) | Bash is an sh-compatible command language interpreter that executes commands read from the standard input or from a file. Bash also incorporates useful features from the Korn and C shells (ksh and csh). |
| [binutils](http://directory.fsf.org/project/binutils/) | binutils: GNU binary utilities |
